@@ -2,7 +2,8 @@
 
 use 5.008;
 use strict;
-no warnings;
+use warnings;
+no warnings 'all';
 
 use File::Basename;
 use File::Spec;
@@ -10,8 +11,8 @@ use Cwd;
 
 BEGIN {
     chdir dirname(__FILE__) or die "$!";
-    chdir '..' or die "$!";
-};
+    chdir '..'              or die "$!";
+}
 
 do "./Build.PL";
 
